@@ -5,7 +5,6 @@ Copyright (c) 2019 - present AppSeed.us
 
 from django.apps import AppConfig
 
-
 class MyConfig(AppConfig):
-    name = 'apps.tasks'
-    label = 'apps_tasks'
+    name  = 'django_tm'
+    label = 'django_tm'
